pub struct PolicyFactory { /* private fields */ }Implementations
Sourceimpl PolicyFactory
impl PolicyFactory
Sourcepub async fn load(
source: impl AsyncRead + Unpin,
data: Data,
entrypoints: Entrypoints,
) -> Result<Self, LoadError>
pub async fn load( source: impl AsyncRead + Unpin, data: Data, entrypoints: Entrypoints, ) -> Result<Self, LoadError>
Load the policy from the given data source.
Errors
Returns an error if the policy can’t be loaded or instantiated.
Sourcepub async fn set_dynamic_data(
&self,
dynamic_data: PolicyData,
) -> Result<bool, LoadError>
pub async fn set_dynamic_data( &self, dynamic_data: PolicyData, ) -> Result<bool, LoadError>
Set the dynamic data for the policy.
The dynamic_data object is merged with the static data given when the
policy was loaded.
Returns true if the data was updated, false if the version
of the dynamic data was the same as the one we already have.
Errors
Returns an error if the data can’t be merged with the static data, or if the policy can’t be instantiated with the new data.
Sourcepub async fn instantiate(&self) -> Result<Policy, InstantiateError>
pub async fn instantiate(&self) -> Result<Policy, InstantiateError>
Create a new policy instance.
Errors
Returns an error if the policy can’t be instantiated with the current dynamic data.